Welcome to ClientVPS Mirrors

Help for package cromwellDashboard
Type: Package
Title: A Dashboard to Visualize Scientific Workflows in 'Cromwell'
Version: 0.5.1
Author: Xiaowei Zhan
Maintainer: Xiaowei Zhan <zhanxw@gmail.com>
Description: A dashboard supports the usage of 'cromwell'. 'Cromwell' is a scientific workflow engine for command line users. This package utilizes 'cromwell' REST APIs and provides these convenient functions: timing diagrams for running workflows, 'cromwell' engine status, a tabular workflow list. For more information about 'cromwell', visit http://cromwell.readthedocs.io.
License: GPL-3
Encoding: UTF-8
LazyData: true
Imports: shiny, shinydashboard, stringr, httr, dplyr, DT
RoxygenNote: 6.0.1
NeedsCompilation: no
Packaged: 2018-08-02 05:42:05 UTC; xzhan9
Repository: CRAN
Date/Publication: 2018-08-02 12:40:13 UTC

Disable proxy by removing environment variables

Description

Disable proxy by removing environment variables

Usage

disableProxy()

Examples

disableProxy()

Start a dashboard for a running cromwell server

Description

Start a dashboard for a running cromwell server

Usage

runCromwellDashboard(url = "127.0.0.1:8000", version = "v33", ...)

Arguments

url

Cromwell server in the format of address:port

version

Cromwell server version

...

additional parameters for shinyApp()

Value

An object that represents the app

Examples

## Not run: 
   runCromwellDashboard("127.0.0.1:8000", "v33")

## End(Not run)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.